ntl: A library for doing number theory
======================================

Description
-----------

NTL is a high-performance, portable C++ library providing data
structures and algorithms for manipulating signed, arbitrary length
integers, and for vectors, matrices, and polynomials over the integers
and over finite fields.

Website: http://www.shoup.net/ntl/

License
-------

-  GNU LGPLv2.1+


Upstream Contact
----------------

-  Victor Shoup - for contact info see http://www.shoup.net/

Special Update/Build Instructions
---------------------------------

-  None
